# Counterpointal

This package is under development. In the meantime, you can look at other packages of related thematics:
* [rl-musician](https://pypi.org/project/rl-musician/)
* [geniartor](https://pypi.org/project/geniartor/)
